export const TYPE_JOIN = 'join'
export const TYPE_DEATH = 'death'

/**
 * Damage caused when an entity contacts a block such as a Cactus.
 * <p>
 * Damage: 1 (Cactus)
 */
export const DEATH_TYPE_CONTACT = 'CONTACT'

/**
 * Damage caused when an entity attacks another entity.
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_ENTITY_ATTACK = 'ENTITY_ATTACK'

/**
 * Damage caused when an entity attacks another entity in a sweep attack.
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_ENTITY_SWEEP_ATTACK = 'ENTITY_SWEEP_ATTACK'

/**
 * Damage caused when attacked by a projectile.
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_PROJECTILE = 'PROJECTILE'

/**
 * Damage caused by being put in a block
 * <p>
 * Damage: 1
 */
export const DEATH_TYPE_SUFFOCATION = 'SUFFOCATION'

/**
 * Damage caused when an entity falls a distance greater than 3 blocks
 * <p>
 * Damage: fall height - 3.0
 */
export const DEATH_TYPE_FALL = 'FALL'

/**
 * Damage caused by direct exposure to fire
 * <p>
 * Damage: 1
 */
export const DEATH_TYPE_FIRE = 'FIRE'

/**
 * Damage caused due to burns caused by fire
 * <p>
 * Damage: 1
 */
export const DEATH_TYPE_FIRE_TICK = 'FIRE_TICK'

/**
 * Damage caused due to a snowman melting
 * <p>
 * Damage: 1
 */
export const DEATH_TYPE_MELTING = 'MELTING'

/**
 * Damage caused by direct exposure to lava
 * <p>
 * Damage: 4
 */
export const DEATH_TYPE_LAVA = 'LAVA'

/**
 * Damage caused by running out of air while in water
 * <p>
 * Damage: 2
 */
export const DEATH_TYPE_DROWNING = 'DROWNING'

/**
 * Damage caused by being in the area when a block explodes.
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_BLOCK_EXPLOSION = 'BLOCK_EXPLOSION'

/**
 * Damage caused by being in the area when an entity, such as a
 * Creeper, explodes.
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_ENTITY_EXPLOSION = 'ENTITY_EXPLOSION'

/**
 * Damage caused by falling into the void
 * <p>
 * Damage: 4 for players
 */
export const DEATH_TYPE_VOID = 'VOID'

/**
 * Damage caused by being struck by lightning
 * <p>
 * Damage: 5
 */
export const DEATH_TYPE_LIGHTNING = 'LIGHTNING'

/**
 * Damage caused by committing suicide using the command "/kill"
 * <p>
 * Damage: 1000
 */
export const DEATH_TYPE_SUICIDE = 'SUICIDE'

/**
 * Damage caused by starving due to having an empty hunger bar
 * <p>
 * Damage: 1
 */
export const DEATH_TYPE_STARVATION = 'STARVATION'

/**
 * Damage caused due to an ongoing poison effect
 * <p>
 * Damage: 1
 */
export const DEATH_TYPE_POISON = 'POISON'

/**
 * Damage caused by being hit by a damage potion or spell
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_MAGIC = 'MAGIC'

/**
 * Damage caused by Wither potion effect
 */
export const DEATH_TYPE_WITHER = 'WITHER'

/**
 * Damage caused by being hit by a falling block which deals damage
 * <p>
 * <b>Note:</b> Not every block deals damage
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_FALLING_BLOCK = 'FALLING_BLOCK'

/**
 * Damage caused in retaliation to another attack by the Thorns
 * enchantment.
 * <p>
 * Damage: 1-4 (Thorns)
 */
export const DEATH_TYPE_THORNS = 'THORNS'

/**
 * Damage caused by a dragon breathing fire.
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_DRAGON_BREATH = 'DRAGON_BREATH'

/**
 * Custom damage.
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_CUSTOM = 'CUSTOM'

/**
 * Damage caused when an entity runs into a wall.
 * <p>
 * Damage: variable
 */
export const DEATH_TYPE_FLY_INTO_WALL = 'FLY_INTO_WALL'

/**
 * Damage caused when an entity steps on {@link Material#MAGMA_BLOCK}.
 * <p>
 * Damage: 1
 */
export const DEATH_TYPE_HOT_FLOOR = 'HOT_FLOOR'

/**
 * Damage caused when an entity is colliding with too many entities due
 * to the maxEntityCramming game rule.
 * <p>
 * Damage: 6
 */
export const DEATH_TYPE_CRAMMING = 'CRAMMING'

/**
 * Damage caused when an entity that should be in water is not.
 * <p>
 * Damage: 1
 */
export const DEATH_TYPE_DRYOUT = 'DRYOUT'
